@@ -7,11 +7,11 @@ Posy::Plugin::TextTemplate - Posy plugin for interpolating with Text::Template.
 
 =head1 VERSION
 
-This describes version B<0.41> of Posy::Plugin::TextTemplate.
+This describes version B<0.42> of Posy::Plugin::TextTemplate.
 
 =cut
 
-our $VERSION = '0.41';
+our $VERSION = '0.42';
 
 =head1 SYNOPSIS
 
@@ -91,13 +91,15 @@ sub init {
     $self->{config}->{tt_entry_right_delim} = 'perl?>'
 	if (!defined $self->{config}->{tt_entry_right_delim});
     # override the error templates
-    $self->{templates}->{content_type}->{error} = 'text/html';
-    $self->{templates}->{head}->{error} =
-		'<html><body><p><font color="red">Error: I\'m afraid this is the first I\'ve heard of a "[==$path_flavour==]" flavoured Posy.  Try dropping the ".[==$path_flavour==]" bit from the end of the URL.</font>';
-    $self->{templates}->{header}->{error} = '<h3>[==$entry_dw==], [==$entry_da==] [==$entry_month==] [==$entry_year==]</h3>';
-    $self->{templates}->{entry}->{error} =
+    $self->{templates}->{content_type}->{default} = 'text/html';
+    $self->{templates}->{head}->{default} =
+		'<html><head><title>[==$config_site_title==]: [==$path_file_key==] ([==$path_flavour==])</title>
+		</head>
+		<body><p>([==$path_basename==].[==$path_flavour==])</p>';
+    $self->{templates}->{header}->{default} = '<h3>[==$entry_dw==], [==$entry_da==] [==$entry_month==] [==$entry_year==]</h3>';
+    $self->{templates}->{entry}->{default} =
 		'<p><b>[==$entry_title==]</b><br />[==$entry_body==] <a href="[==$url==]/[==$path_cat_id==]/[==$path_basename==].[==$config_flavour==]">#</a></p>';
-    $self->{templates}->{foot}->{error} = '</body></html>';
+    $self->{templates}->{foot}->{default} = '</body></html>';
 
 } # init
 
